import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Creates an *investigation group* in your account.
 *
 * Creating an investigation group is a one-time setup task for each Region in your account. It is a necessary task to be able to perform investigations.
 *
 * Settings in the investigation group help you centrally manage the common properties of your investigations, such as the following:
 *
 * - Who can access the investigations
 * - Whether investigation data is encrypted with a customer managed AWS Key Management Service key.
 * - How long investigations and their data are retained by default.
 *
 * Currently, you can have one investigation group in each Region in your account. Each investigation in a Region is a part of the investigation group in that Region
 *
 * To create an investigation group and set up Amazon Q Developer operational investigations, you must be signed in to an IAM principal that has the either the `AIOpsConsoleAdminPolicy` or the `AdministratorAccess` IAM policy attached, or to an account that has similar permissions.
 *
 * > You can optionally configure CloudWatch alarms to start investigations and add events to investigations. The examples section on this page demonstrates creating an investigation group and an alarm at the same time.
 * >
 * > For more information about configuring CloudWatch alarms to work with Amazon Q Developer operational investigations, see
 *
 * @cloudformationResource AWS::AIOps::InvestigationGroup
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html
 */
export declare class CfnInvestigationGroup extends cdk.CfnResource implements cdk.IInspectable, cdk.ITaggableV2 {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnInvestigationGroup from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnInvestigationGroup;
    /**
     * The Amazon Resource Name (ARN) of the investigation group. For example, `arn:aws:aiops: *Region* : *account-id* :investigation-group: *investigation-group-id*`
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The date and time that the investigation group was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The name of the user who created the investigation group.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * The date and time that the investigation group was most recently modified.
     *
     * @cloudformationAttribute LastModifiedAt
     */
    readonly attrLastModifiedAt: string;
    /**
     * The name of the user who most recently modified the investigation group.
     *
     * @cloudformationAttribute LastModifiedBy
     */
    readonly attrLastModifiedBy: string;
    /**
     * Tag Manager which manages the tags for this resource
     */
    readonly cdkTagManager: cdk.TagManager;
    /**
     * Use this property to integrate Amazon Q Developer operational investigations with Amazon Q in chat applications.
     */
    chatbotNotificationChannels?: Array<CfnInvestigationGroup.ChatbotNotificationChannelProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An array of cross account configurations.
     */
    crossAccountConfigurations?: Array<CfnInvestigationGroup.CrossAccountConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Use this property to specify a customer managed AWS KMS key to encrypt your investigation data.
     */
    encryptionConfig?: CfnInvestigationGroup.EncryptionConfigMapProperty | cdk.IResolvable;
    /**
     * Investigation Group policy.
     */
    investigationGroupPolicy?: string;
    /**
     * Specify `true` to enable Amazon Q Developer operational investigations to have access to change events that are recorded by CloudTrail .
     */
    isCloudTrailEventHistoryEnabled?: boolean | cdk.IResolvable;
    /**
     * A name for the investigation group.
     */
    name: string;
    /**
     * Specify how long that investigation data is kept. For more information, see [Operational investigation data retention](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Investigations-Retention.html) .
     */
    retentionInDays?: number;
    /**
     * Specify the ARN of the IAM role that Amazon Q Developer operational investigations will use when it gathers investigation data.
     */
    roleArn?: string;
    /**
     * Enter the existing custom tag keys for custom applications in your system.
     */
    tagKeyBoundaries?: Array<string>;
    /**
     * A list of key-value pairs to associate with the investigation group.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnInvestigationGroupProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnInvestigationGroup {
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html
     */
    interface EncryptionConfigMapProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html#cfn-aiops-investigationgroup-encryptionconfigmap-encryptionconfigurationtype
         */
        readonly encryptionConfigurationType?: string;
        /**
         * If the investigation group uses a customer managed key for encryption, this field displays the ID of that key.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-encryptionconfigmap.html#cfn-aiops-investigationgroup-encryptionconfigmap-kmskeyid
         */
        readonly kmsKeyId?: string;
    }
    /**
     * This structure is a string array.
     *
     * The first string is the ARN of a Amazon SNS topic. The array of strings display the ARNs of Amazon Q in chat applications configurations that are associated with that topic. For more information about these configuration ARNs, see [Getting started with Amazon Q in chat applications](https://docs.aws.amazon.com/chatbot/latest/adminguide/getting-started.html) and [Resource type defined by AWS Chatbot](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awschatbot.html#awschatbot-resources-for-iam-policies) .
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html
     */
    interface ChatbotNotificationChannelProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html#cfn-aiops-investigationgroup-chatbotnotificationchannel-chatconfigurationarns
         */
        readonly chatConfigurationArns?: Array<string>;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-chatbotnotificationchannel.html#cfn-aiops-investigationgroup-chatbotnotificationchannel-snstopicarn
         */
        readonly snsTopicArn?: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-crossaccountconfiguration.html
     */
    interface CrossAccountConfigurationProperty {
        /**
         * The Investigation Role's ARN.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-aiops-investigationgroup-crossaccountconfiguration.html#cfn-aiops-investigationgroup-crossaccountconfiguration-sourcerolearn
         */
        readonly sourceRoleArn?: string;
    }
}
/**
 * Properties for defining a `CfnInvestigationGroup`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html
 */
export interface CfnInvestigationGroupProps {
    /**
     * Use this property to integrate Amazon Q Developer operational investigations with Amazon Q in chat applications.
     *
     * This property is an array. For the first string, specify the ARN of an Amazon SNS topic. For the array of strings, specify the ARNs of one or more Amazon Q in chat applications configurations that you want to associate with that topic. For more information about these configuration ARNs, see [Getting started with Amazon Q in chat applications](https://docs.aws.amazon.com/chatbot/latest/adminguide/getting-started.html) and [Resource type defined by AWS Chatbot](https://docs.aws.amazon.com/service-authorization/latest/reference/list_awschatbot.html#awschatbot-resources-for-iam-policies) .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-chatbotnotificationchannels
     */
    readonly chatbotNotificationChannels?: Array<CfnInvestigationGroup.ChatbotNotificationChannelProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * An array of cross account configurations.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-crossaccountconfigurations
     */
    readonly crossAccountConfigurations?: Array<CfnInvestigationGroup.CrossAccountConfigurationProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Use this property to specify a customer managed AWS KMS key to encrypt your investigation data.
     *
     * If you omit this property, Amazon Q Developer operational investigations will use an AWS key to encrypt the data. For more information, see [Encryption of investigation data](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Investigations-Security.html#Investigations-KMS) .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-encryptionconfig
     */
    readonly encryptionConfig?: CfnInvestigationGroup.EncryptionConfigMapProperty | cdk.IResolvable;
    /**
     * Investigation Group policy.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-investigationgrouppolicy
     */
    readonly investigationGroupPolicy?: string;
    /**
     * Specify `true` to enable Amazon Q Developer operational investigations to have access to change events that are recorded by CloudTrail .
     *
     * The default is `true` .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-iscloudtraileventhistoryenabled
     */
    readonly isCloudTrailEventHistoryEnabled?: boolean | cdk.IResolvable;
    /**
     * A name for the investigation group.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-name
     */
    readonly name: string;
    /**
     * Specify how long that investigation data is kept. For more information, see [Operational investigation data retention](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Investigations-Retention.html) .
     *
     * If you omit this parameter, the default of 90 days is used.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-retentionindays
     */
    readonly retentionInDays?: number;
    /**
     * Specify the ARN of the IAM role that Amazon Q Developer operational investigations will use when it gathers investigation data.
     *
     * The permissions in this role determine which of your resources that Amazon Q Developer operational investigations will have access to during investigations.
     *
     * For more information, see [How to control what data Amazon Q has access to during investigations](https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Investigations-Security.html#Investigations-Security-Data) .
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-rolearn
     */
    readonly roleArn?: string;
    /**
     * Enter the existing custom tag keys for custom applications in your system.
     *
     * Resource tags help Amazon Q narrow the search space when it is unable to discover definite relationships between resources. For example, to discover that an Amazon ECS service depends on an Amazon RDS database, Amazon Q can discover this relationship using data sources such as X-Ray and CloudWatch Application Signals. However, if you haven't deployed these features, Amazon Q will attempt to identify possible relationships. Tag boundaries can be used to narrow the resources that will be discovered by Amazon Q in these cases.
     *
     * You don't need to enter tags created by myApplications or AWS CloudFormation , because Amazon Q can automatically detect those tags.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-tagkeyboundaries
     */
    readonly tagKeyBoundaries?: Array<string>;
    /**
     * A list of key-value pairs to associate with the investigation group.
     *
     * You can associate as many as 50 tags with an investigation group.
     *
     * Tags can help you organize and categorize your resources.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-aiops-investigationgroup.html#cfn-aiops-investigationgroup-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
